@@ -18,6 +18,8 @@ class PraatLoader:
         self.init_scripts()
 
     def init_scripts(self):
+        if not os.path.isdir(self.script_dir):
+            os.mkdir(self.script_dir)
         for s in self.scripts:
             if os.path.isfile(os.path.join(self.script_dir,s)):
                 continue
